@@ -1,16 +1,18 @@
 #!/bin/bash
 
 apt-get update -qy && apt-get install -qy --no-install-recommends \
-    asciidoctor \
-    cvs \
-    cvs-fast-export \
-    golang \
-    golint \
-    mercurial \
-    rsync \
-    shellcheck \
-    subversion \
-    time \
+			      asciidoctor \
+			      brz \
+			      bzr \
+			      cvs \
+			      cvs-fast-export \
+			      golang \
+			      golint \
+			      mercurial \
+			      rsync \
+			      shellcheck \
+			      subversion \
+			      time \
  && apt-get clean \
  && rm -rf /var/lib/apt/lists/*
 type go
