@@ -17,7 +17,9 @@ import (
 	"sync"
 	"time"
 
+	termios "github.com/pkg/term/termios"
 	terminfo "github.com/xo/terminfo"
+	term "golang.org/x/term"
 )
 
 // Baton is the overall state of the output
@@ -25,7 +27,6 @@ type Baton struct {
 	progressEnabled bool
 	logFunc         func(string)
 	stream          *os.File
-	channel         chan Message
 	start           time.Time
 	twirly          Twirly
 	counter         Counter
@@ -49,7 +50,9 @@ type Counter struct {
 	count      uint64
 }
 
-// Progress is the evolved form of the counter which shows the percentage of completion and the rate of progress in addition to the count
+// Progress is the evolved form of the counter which shows the
+// percentage of completion and the rate of progress in addition to
+// the count
 type Progress struct {
 	sync.RWMutex
 	start      time.Time
@@ -80,16 +83,22 @@ const (
 	// PROGRESS messages are printed to the status line,
 	// overwriting whatever was already there
 	PROGRESS
-	// SYNC allows for synchronization between the goroutine and
-	// the calling code; the goroutine replies but takes no other
-	// action
-	SYNC
 )
 
-// Message is content for a baton display
-type Message struct {
-	ty  msgType
-	str []byte
+var ti *terminfo.Terminfo
+
+func init() {
+	var err error
+	ti, err = terminfo.LoadFromEnv()
+	if err != nil {
+		for _, termtype := range []string{os.Getenv("TERM"), "xterm", "vt100", "dumb"} {
+			ti, err = terminfo.Load(termtype)
+			if err == nil {
+				return
+			}
+		}
+		panic("no terminfo database available")
+	}
 }
 
 const twirlInterval = 100 * time.Millisecond // Rate-limit baton twirls
@@ -101,71 +110,63 @@ const progressInterval = 1 * time.Second     // Rate-limit progress messages
 func newBaton(interactive bool, logFunc func(string)) *Baton {
 	me := new(Baton)
 	me.start = time.Now()
-	me.channel = make(chan Message)
 	me.progressEnabled = interactive
 	me.logFunc = logFunc
-	go func() {
-		lastProgress := &[]byte{}
-		for {
-			msg := <-me.channel
-			if msg.ty == SYNC {
-				me.channel <- msg
-			} else if me.stream != nil {
-				if msg.ty == LOG {
-					if me.progressEnabled {
-						control.ti().Fprintf(me.stream, terminfo.ColumnAddress, 0)
-						control.ti().Fprintf(me.stream, terminfo.ClrEol)
-						me.stream.Write(msg.str)
-						if !bytes.HasSuffix(msg.str, control.ti().Strings[terminfo.ScrollForward]) {
-							control.ti().Fprintf(me.stream, terminfo.ScrollForward)
-						}
-						control.ti().Fprintf(me.stream, terminfo.ColumnAddress, 0)
-						me.stream.Write(*lastProgress)
-					} else {
-						if len(msg.str) != 0 {
-							me.stream.Write(msg.str)
-						}
-						if !bytes.HasSuffix(msg.str, []byte{'\n'}) {
-							me.stream.Write([]byte{'\n'})
-						}
-					}
-				} else if msg.ty == PROGRESS {
-					control.ti().Fprintf(me.stream, terminfo.ColumnAddress, 0)
-					control.ti().Fprintf(me.stream, terminfo.ClrEol)
-					me.stream.Write(msg.str)
-					lastProgress = &msg.str
-				}
-			}
-		}
-	}()
 	me.stream = os.Stdout
 
 	return me
 }
 
-func (baton *Baton) setInteractivity(enabled bool) {
-	if baton != nil {
-		baton.channel <- Message{SYNC, nil}
-		baton.progressEnabled = enabled
-		<-baton.channel
+func (baton *Baton) progressWrite(ty msgType, payload []byte) {
+	if baton.stream != nil {
+		if ty == LOG {
+			if baton.progressEnabled {
+				ti.Fprintf(baton.stream, terminfo.CarriageReturn)
+				ti.Fprintf(baton.stream, terminfo.ClrEol)
+				baton.stream.Write(payload)
+				if !bytes.HasSuffix(payload, ti.Strings[terminfo.ScrollForward]) {
+					ti.Fprintf(baton.stream, terminfo.ScrollForward)
+				}
+				ti.Fprintf(baton.stream, terminfo.CarriageReturn)
+				if term.IsTerminal(int(baton.stream.Fd())) {
+					termios.Tcdrain(baton.stream.Fd())
+				}
+			} else {
+				if len(payload) != 0 {
+					baton.stream.Write(payload)
+				}
+				if !bytes.HasSuffix(payload, []byte{'\n'}) {
+					baton.stream.Write([]byte{'\n'})
+				}
+			}
+		} else if ty == PROGRESS {
+			ti.Fprintf(baton.stream, terminfo.CarriageReturn)
+			ti.Fprintf(baton.stream, terminfo.ClrEol)
+			baton.stream.Write(payload)
+		}
 	}
 }
 
-// log prints out a simple log message
+func (baton *Baton) setInteractivity(enabled bool) {
+	baton.progressEnabled = enabled
+}
+
+// printLog prints out a simple log message
 func (baton *Baton) printLog(str []byte) {
 	if baton != nil {
 		if baton.progressEnabled {
-			baton.channel <- Message{LOG, _copyb(str)}
+			baton.progressWrite(LOG, str)
 		} else {
 			baton.stream.Write(str)
 		}
 	}
 }
 
+// printLogString prints out a simple log message
 func (baton *Baton) printLogString(str string) {
 	if baton != nil {
 		if baton.progressEnabled {
-			baton.channel <- Message{LOG, _copystr(str)}
+			baton.progressWrite(LOG, []byte(str))
 		} else {
 			baton.stream.WriteString(str)
 		}
@@ -177,7 +178,7 @@ func (baton *Baton) printProgress() {
 	if baton != nil && baton.progressEnabled {
 		var buf bytes.Buffer
 		baton.render(&buf)
-		baton.channel <- Message{PROGRESS, _copyb(buf.Bytes())}
+		baton.progressWrite(PROGRESS, buf.Bytes())
 	}
 }
 
@@ -219,7 +220,7 @@ func (baton *Baton) endProcess(endmsg ...string) {
 			baton.process.endmsg)
 		baton.process.startmsg = nil
 		baton.process.endmsg = nil
-		baton.channel <- Message{PROGRESS, nil}
+		baton.progressWrite(PROGRESS, nil)
 	}
 }
 
@@ -255,7 +256,7 @@ func (baton *Baton) endcounter() {
 		defer baton.counter.Unlock()
 		baton.counter.format = ""
 		baton.counter.count = 0
-		baton.channel <- Message{PROGRESS, nil}
+		baton.progressWrite(PROGRESS, nil)
 	}
 }
 
@@ -299,12 +300,12 @@ func (baton *Baton) endProgress() {
 		baton.progress.tag = nil
 		baton.progress.count = 0
 		baton.progress.expected = 0
-		baton.channel <- Message{PROGRESS, nil}
+		baton.progressWrite(PROGRESS, nil)
 		baton.progress.Unlock()
 	}
 }
 
-// Write ships a log message to be displayed by te baton
+// Write ships a log message to be displayed by the baton
 func (baton *Baton) Write(b []byte) (n int, err error) {
 	if baton != nil {
 		baton.printLog(b)
@@ -317,14 +318,6 @@ func (baton *Baton) Close() error {
 	return nil
 }
 
-// Sync forces ourt pending messages from a baton
-func (baton *Baton) Sync() {
-	if baton != nil {
-		baton.channel <- Message{SYNC, nil}
-		<-baton.channel
-	}
-}
-
 func (baton *Baton) render(buf io.Writer) {
 	baton.process.renderPre(buf)
 	baton.counter.render(buf)
@@ -338,7 +331,7 @@ func (baton *Twirly) render(b io.Writer) {
 	baton.RLock()
 	defer baton.RUnlock()
 	character := "-\\|/"[baton.count]
-	b.Write([]byte{32, character})
+	b.Write([]byte{' ', character})
 }
 
 func (baton *Counter) render(b io.Writer) {
@@ -404,27 +397,4 @@ func (baton *Process) renderPost(b io.Writer) {
 	b.Write(baton.endmsg)
 }
 
-func _copystr(s string) []byte {
-	temp := make([]byte, len(s))
-	copy(temp, s)
-	return temp
-}
-
-func _copyb(s []byte) []byte {
-	temp := make([]byte, len(s))
-	copy(temp, s)
-	return temp
-}
-
-func getTerminfoBytes(cap string, params ...string) []byte {
-	reader, _, err := readFromProcess("tput " + cap + " " + strings.Join(params, " "))
-	if err != nil {
-		return nil
-	}
-	buf := new(bytes.Buffer)
-	_, err = buf.ReadFrom(reader)
-	if err != nil {
-		return nil
-	}
-	return buf.Bytes()
-}
+// end
