@@ -5,5 +5,6 @@
 # are only done on selected revisions.
 # The output file should not contain XX
 # because WI is not a segment match.
-${REPOCUTTER:-repocutter} -r 3:5 -q pathrename README WOBBLE WOBBLE WIBBLE WI XX <vanilla.svn
+# shellcheck disable=SC2086
+${REPOCUTTER:-repocutter} -r 3:5 -q -t "$(basename $0)" pathrename README WOBBLE WOBBLE WIBBLE WI XX <vanilla.svn 2>&1
 
