@@ -1,6 +1,7 @@
-## Test update (-u) mode of repomapper
+#!/bin/sh
+## Test processing of additional maps in repomapper
 
-trap "rm -f /tmp/contrib$$ /tmp/update$$" 0 12 2 15
+trap 'rm -f /tmp/contrib$$ /tmp/update$$' EXIT HUP INT QUIT TERM
 
 cat >/tmp/contrib$$ <<EOF
 fubar = J. Random Fubar <j@random.net>
@@ -12,6 +13,6 @@ foonly = Fred Foonly <fred@foonly.net>
 EOF
 
 # Only the foonly line should be merged.
-${REPOMAPPER:-repomapper} -u /tmp/update$$ /tmp/contrib$$
+${REPOMAPPER:-repomapper} /tmp/contrib$$ /tmp/update$$ 
 
 #end
