@@ -14,8 +14,10 @@ EOF
 
 # No user-serviceable parts below this line
 
-command -v svn >/dev/null 2>&1 || { echo "    Skipped, svn missing."; exit 0; }
-command -v git >/dev/null 2>&1 || { echo "    Skipped, git missing."; exit 0; }
+# shellcheck disable=SC1091
+. ./common-setup.sh
+
+need svn git
 
 trap 'rm -rf /tmp/test-repo$$-svn /tmp/test-repo$$-git /tmp/test-repo$$-svn-checkout /tmp/out$$ /tmp/altered$$' EXIT HUP INT QUIT TERM
 
@@ -24,13 +26,6 @@ reposurgeon "read <${stem}.svn" "msgin --blobs </tmp/altered$$" "prefer git" "re
 # shellcheck disable=SC2086
 ${REPOTOOL:-repotool} compare ${TESTOPT} /tmp/test-repo$$-svn-checkout /tmp/test-repo$$-git 2>&1 | sed -e "s/$$/\$\$/"g >>/tmp/out$$
 
-
-case $1 in
-    --regress)
-        diff --text -u repotool-compare-svn-git-failed.chk /tmp/out$$ || ( echo "$0: FAILED"; exit 1 ); ;;
-    --rebuild)
-	cat /tmp/out$$ >repotool-compare-svn-git-failed.chk;;
-    --view)
-	cat /tmp/out$$;;
-esac
+toolmeta "$1" /tmp/out$$
 	      
+# end
