@@ -5,7 +5,7 @@ mkdir /tmp/test-workdir$$
 cd /tmp/test-workdir$$ >/dev/null || ( echo "$0: cd failed" >&2; exit 1 )
 ${REPOTOOL:-repotool} initialize xyzzy svn hg >/tmp/out$$
 echo Return code: $? >>/tmp/out$$
-cd - >/dev/null >/dev/null || ( echo "$0: cd failed" >&2; exit 1 )
+cd - >/dev/null || ( echo "$0: cd failed" >&2; exit 1 )
 ./dir-md5 /tmp/test-workdir$$ >>/tmp/out$$
 
 # shellcheck disable=SC1091
