@@ -29,6 +29,8 @@ import (
 	term "golang.org/x/term"
 )
 
+var version string // Patched by -X option in Makefile
+
 // Define a couplee of partial capability tables for querying
 // checkout directories.
 
@@ -65,7 +67,7 @@ var makefileTemplate = `# Makefile for {{.Project}} conversion using reposurgeon
 # 1. Make sure reposurgeon and repotool are on your $PATH.
 # 2. (Skip this step if you're starting from a stream file.) For svn, set
 #    REMOTE_URL to point at the remote repository you want to convert;
-#    you can use either an svn: URL or an rsync: URL for this.
+#    you can use either an svn: URL, an rsync: URL, or a p4: URL for this.
 #    If the repository is already in a DVCS such as hg or git,
 #    set REMOTE_URL to either the normal cloning URL (starting with hg://,
 #    git://, etc.) or to the path of a local clone.
@@ -96,8 +98,7 @@ var makefileTemplate = `# Makefile for {{.Project}} conversion using reposurgeon
 
 EXTRAS = 
 REMOTE_URL = svn://svn.debian.org/{{.Project}}
-#REMOTE_URL = https://{{.Project}}.googlecode.com/svn/
-CVS_HOST = {{.Project}}.cvs.sourceforge.net
+CVS_HOST = cvs.sourceforge.net
 #CVS_HOST = cvs.savannah.gnu.org
 CVS_MODULE = {{.Project}}
 #REMOTE_URL = cvs://$(CVS_HOST)/{{.Project}}\#$(CVS_MODULE)
@@ -108,7 +109,7 @@ VERBOSITY = "set progress"
 REPOSURGEON = reposurgeon
 LOGFILE = conversion.log
 
-# Set and uncomment these if remote access tio Subversion needs credentials.
+# Set and uncomment these if remote access to Subversion needs credentials.
 #export RUSERNAME=
 #export RPASSWORD=
 
@@ -521,6 +522,29 @@ func mirror(args []string) {
 			}
 		})
 		baton.endProgress()
+	} else if strings.HasPrefix("p4://", operand) {
+		// According to
+		// https://stackoverflow.com/questions/31051732/perforce-to-git-migration,
+		// the clone operation will create a live Git repository capturing the
+		// Perforce history.
+		operand = operand[3:]
+		if mirrordir == "" {
+			locald = filepath.Join(pwd, filepath.Base(operand)+"-mirror")
+		} else if mirrordir[0] == os.PathSeparator {
+			locald = mirrordir
+		} else {
+			locald = filepath.Join(pwd, mirrordir)
+		}
+		cmd := ""
+		legend := ""
+		if isdir(mirrordir) {
+			cmd = "git p4 sync --import-labels --detect-branches --destination %s %s@all"
+			legend = "p4 syncing"
+		} else {
+			cmd = fmt.Sprintf("git p4 clone --import-labels --detect-branches --destination %s %s@all")
+			legend = "p4 cloning"
+		}
+		runShellProcessOrDie(fmt.Sprintf(cmd, mirrordir, operand), legend)
 	} else if isdir(filepath.Join(operand, "locks")) {
 		if operand[0] == os.PathSeparator {
 			locald = operand
@@ -805,6 +829,8 @@ func checkout(outdir string, rev string) string {
 		return outdir
 	} else if vcs.name == "bzr" {
 		croak("checkout is not yet supported in bzr.")
+	} else if vcs.name == "brz" {
+		croak("checkout is not yet supported in bzr.")
 	} else if vcs.name == "hg" {
 		spec := ""
 		if rev != "" {
@@ -1190,10 +1216,10 @@ as Subversion dump files; the point is to be a lossless
 representation, or as close to one as possible.
 `},
 	"mirror": {
-		"mirror [URL] localdir",
+		"mirror {URL|localdir} [localname]",
 		"create or update a mirror of the source repository",
 		`The 'mirror' action makes or updates a local mirror of a
-Subversion, CVS, git, or hg repo. It requires a single argument,
+Subversion, CVS, git, hg, or p4 repo. It requires an argument,
 either a repository URL or the name of a local mirror directory
 created by a previous run. The first form creates a local mirror of
 the repository in a directory named after the last segment of the URL,
@@ -1207,15 +1233,17 @@ mirroring.
 Subversion URLs are as specified in the public documentation for
 Subversion.  CVS URLs must specify a host and repository path,
 followed by a '#', followed by a module name.  URLs for git and hg
-should be in the form normally used for clone commands.
-Alternatively, a repository URL may be a "file://" URL, in which
+should be in the form normally used for clone commands.  Perforce
+(p4) URLs must specify host, path, and depot (project).
+
+The mirror command can also be passed an rsync URL (service prefix
+"rsync://").  This will usually be faster than mirroring through an
+equivalent Subversion URL.
+
+Finally, a repository URL may be a "file://" URL, in which
 case the repository type is autodetected from the contents of
 the indicated directory. Note: A Subversion file URL has *three*
 slashes after the "file:" prefix!
-
-The mirror command can also be passed an rsync URL.  This
-will usually be faster than mirroring through an equivalent
-Subversion URL.
 `},
 	"branches": {
 		"branches",
